severity = brutal
verbose = 8
exclude = Bangs::ProhibitFlagComments Documentation::RequirePodAtEnd Editor::RequireEmacsFileVariables Miscellanea::RequireRcsKeywords Modules::RequireExplicitInclusion Modules::RequireExplicitPackage Modules::RequirePerlVersion Tics::ProhibitLongLines

[Lax::RequireExplicitPackage::ExceptForPragmata]
allowed_pragmata = diagnostics feature perlversion strict warnings utf8

[CodeLayout::RequireTidyCode]
perltidyrc = xt/author/perltidy.rc

# since we're using Modern::Perl
[Compatibility::PerlMinimumVersionAndWhy]
above_version = 5.010
[Compatibility::PodMinimumVersion]
above_version = 5.010

[ControlStructures::ProhibitPostfixControls]
flowcontrol = carp cluck confess croak die exit goto warn exit pod2usage

[Documentation::PodSpelling]
stop_words = bugtracker superclass cwd setcwd rget rput rremove mget mput readline getc eof sftpread sftpwrite opendir closedir readdir fstat lstat setstat fsetstat mkdir mkpath rmdir readlink symlink hardlink statvs fstatvs Perldoc perldoc annonations PASSed

[Documentation::RequirePodSections]
lib_sections = NAME | VERSION | SYNOPSIS | DESCRIPTION | SUPPORT | AUTHOR | COPYRIGHT AND LICENSE
script_sections = NAME | USAGE | DESCRIPTION | CONFIGURATION | SUPPORT | AUTHOR | COPYRIGHT AND LICENSE

[InputOutput::RequireCheckedSyscalls]
functions = :builtins
exclude_functions = print say

[Subroutines::ProhibitCallsToUndeclaredSubs]
exempt_subs = Carp::croak Moose::around Moose::extends

[TestingAndDebugging::RequireUseStrict]
equivalent_modules = Modern::Perl

[TestingAndDebugging::RequireUseWarnings]
equivalent_modules = Modern::Perl
